Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(300)

Unified Diff: chrome/browser/ui/views/frame/immersive_mode_controller_ash.h

Issue 14634003: Fix the size of the tabs when exiting immersive fullscreen with the tab indicators hidden (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/views/frame/immersive_mode_controller_ash.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/frame/immersive_mode_controller_ash.h
diff --git a/chrome/browser/ui/views/frame/immersive_mode_controller_ash.h b/chrome/browser/ui/views/frame/immersive_mode_controller_ash.h
index 29c7bc9ded08cd9fbad4e4dcbccdf06f742e4a52..b123738370e679174ba5783364e8bb1041b21179 100644
--- a/chrome/browser/ui/views/frame/immersive_mode_controller_ash.h
+++ b/chrome/browser/ui/views/frame/immersive_mode_controller_ash.h
@@ -148,9 +148,8 @@ class ImmersiveModeControllerAsh : public ImmersiveModeController,
// Enables or disables layer-based painting to allow smooth animations.
void EnablePaintToLayer(bool enable);
- // Updates layout for |browser_view_| including window caption controls and
- // tab strip style |immersive_style|.
- void LayoutBrowserView(bool immersive_style);
+ // Updates the browser root view's layout including window caption controls.
+ void LayoutBrowserRootView();
// Called when the animation to slide open the top-of-window views has
// completed.
« no previous file with comments | « no previous file | chrome/browser/ui/views/frame/immersive_mode_controller_ash.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698